@@ -3,4 +3,4 @@
 # House keep 
 #############################
 
-python /opt/tandbergtv/cms/cronjob/HouseKeeper.pyc
\ No newline at end of file
+sudo python /opt/tandbergtv/cms/cronjob/HouseKeeper.pyc
\ No newline at end of file
