@@ -12,7 +12,7 @@
 # Description:
 # A script for install/update cms cron job(s)
 
-echo "Install cron job begin..."
+sudo echo "Install cron job begin..."
 
 
 datestamp=`date '+%Y%m%d%H%M%S'`
@@ -22,17 +22,17 @@ HOUSEKEEP_CMD=cms-file-housekeep.sh
 HOUSEKEEP_CMD_PATH=/opt/tandbergtv/cms/cronjob/cms-file-housekeep.sh
 
 
-chown nobody:nobody $HOUSEKEEP_CMD_PATH
-chmod +x $HOUSEKEEP_CMD_PATH
-crontab -u nobody -l > /tmp/cron.${datestamp}
-cp /tmp/cron.${datestamp} /tmp/cron.${datestamp}.bak
+sudo chown nobody:nobody $HOUSEKEEP_CMD_PATH
+sudo chmod +x $HOUSEKEEP_CMD_PATH
+sudo sh -c  "crontab -u nobody -l > /tmp/cron.${datestamp}"
+sudo cp /tmp/cron.${datestamp} /tmp/cron.${datestamp}.bak
 
-sed -i "s/.*${HOUSEKEEP_CMD}.*//g"  /tmp/cron.${datestamp}
-sed -i '/^$/d' /tmp/cron.${datestamp}
-echo "${HOUSEKEEP_CRON_EXP} ${HOUSEKEEP_CMD_PATH}" >> /tmp/cron.${datestamp}
+sudo sed -i "s/.*${HOUSEKEEP_CMD}.*//g"  /tmp/cron.${datestamp}
+sudo sed -i '/^$/d' /tmp/cron.${datestamp}
+sudo sh -c  "echo \"${HOUSEKEEP_CRON_EXP} ${HOUSEKEEP_CMD_PATH}\" >> /tmp/cron.${datestamp}"
 
-crontab -u nobody /tmp/cron.${datestamp}
+sudo crontab -u nobody /tmp/cron.${datestamp}
 
-echo "Install cron job done"
+sudo echo "Install cron job done"
 
 exit;
