@@ -12,7 +12,7 @@
 # Description:
 # Use Shell to do additional jobs after installation is done, mainly for upgrading.
 #
-echo "POST INSTALLATION: Do something additional after installation.."
+sudo echo "POST INSTALLATION: Do something additional after installation.."
 
 SUB_SYSTEM_PATH=/opt/tandbergtv/cms/workflow/plugins/subsystems
 
@@ -23,20 +23,20 @@ do
 	dir="$SUB_SYSTEM_PATH/$ss"
 	if [ -d "$dir" ]
 	then
-		rm -rf "$dir"
-		echo "Removed Directory $dir"
+		sudo rm -rf "$dir"
+		sudo echo "Removed Directory $dir"
 	else
-		echo "Directory not exists: $dir"
+		sudo echo "Directory not exists: $dir"
 	fi
 done
 
 CF_DATATYPE_MAPPING_DAT=/opt/tandbergtv/cms/plugins/content/com.tandbergtv.metadata/resources/cfDataTypeMapping.dat
 if [ -f "$CF_DATATYPE_MAPPING_DAT" ] 
 then
-    echo "remove $CF_DATATYPE_MAPPING_DAT"
-    rm -rf $CF_DATATYPE_MAPPING_DAT
+    sudo echo "remove $CF_DATATYPE_MAPPING_DAT"
+    sudo rm -rf $CF_DATATYPE_MAPPING_DAT
 else
-    echo "$CF_DATATYPE_MAPPING_DAT does not exists!"
+    sudo echo "$CF_DATATYPE_MAPPING_DAT does not exists!"
 fi
 
-echo "POST INSTALLATION: done.."
\ No newline at end of file
+sudo echo "POST INSTALLATION: done.."
\ No newline at end of file
