@@ -1,7 +1,7 @@
 #!/bin/sh
 source /etc/bashrc
 if [ -e ./scripts/filesync.py ]; then
-    python ./scripts/filesync.py
+    sudo python ./scripts/filesync.py
 else
-    python ./scripts/filesync.pyc
+    sudo python ./scripts/filesync.pyc
 fi
